//!
//!

use super::models;
use crate::repositories;
use diesel::{result::Error, sql_query, RunQueryDsl};

pub struct Composition {
  site_repository: repositories::site::repository::Repository,
}

impl std::fmt::Debug for Composition {
  fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
    f.debug_struct("Composition of members").finish()
  }
}

impl Default for Composition {
  fn default() -> Self {
    Self::new()
  }
}

impl Composition {
  ///
  pub fn new() -> Composition {
    Composition {
      site_repository: repositories::site::repository::Repository::new(),
    }
  }

  ///
  pub fn select_by_url(
    &self,
    conn: &diesel::PgConnection,
    url: Option<String>,
    site_id: uuid::Uuid,
  ) -> Result<Option<repositories::site::models::Site>, Error> {
    let site_url = match url {
      Some(site_url) => site_url,
      None => {
        return Ok(None);
      }
    };
    let ms = match self.site_repository.select(conn, site_id)? {
      Some(s) => s,
      None => {
        return Ok(None);
      }
    };

    if ms.url.eq("*") {
      return Ok(Some(ms));
    }

    if !ms.url.eq(&site_url) {
      return Ok(None);
    }

    Ok(Some(ms))
  }
}
