use super::schema::member_bank_accounts;
use beteran_common_rust as bcr;

///
#[derive(Eq, Hash, Identifiable, Queryable, PartialEq, Debug, Clone)]
#[table_name = "member_bank_accounts"]
pub struct MemberBankAccount {
  ///
  pub id: uuid::Uuid,
  ///
  pub member_id: uuid::Uuid,
  ///
  pub bank_id: uuid::Uuid,
  ///
  pub name: String,
  ///
  pub account_number: String,
  ///
  pub exchange_password: String,
  ///
  pub memo: Option<String>,
  ///
  pub created_at: i64,
  ///
  pub updated_at: i64,
}

///
#[derive(Insertable, Debug, Clone)]
#[table_name = "member_bank_accounts"]
pub struct NewMemberBankAccount {
  ///
  pub member_id: uuid::Uuid,
  ///
  pub bank_id: uuid::Uuid,
  ///
  pub name: String,
  ///
  pub account_number: String,
  ///
  pub exchange_password: String,
  ///
  pub memo: Option<String>,
}

///
#[derive(AsChangeset, Debug, Clone)]
#[table_name = "member_bank_accounts"]
pub struct ModifyMemberBankAccount {
  ///
  pub bank_id: uuid::Uuid,
  ///
  pub name: String,
  ///
  pub account_number: String,
  ///
  pub memo: Option<String>,
}

///
#[derive(AsChangeset, Debug, Clone)]
#[table_name = "member_bank_accounts"]
pub struct ModifyMemberBankAccountForExchangePassword {
  ///
  pub exchange_password: String,
}

///
#[derive(Debug, Clone)]
pub struct FindAllSearch {
  ///
  pub member_id: Option<uuid::Uuid>,
  ///
  pub bank_id: Option<uuid::Uuid>,
  ///
  pub name_like: Option<String>,
  ///
  pub account_number_like: Option<String>,
  ///
  pub memo_like: Option<String>,
}

///
#[derive(Debug, Clone)]
pub struct FindAll {
  ///
  pub search: Option<FindAllSearch>,
  ///
  pub pagination: Option<bcr::models::pagination::Pagination>,
  ///
  pub sorts: Option<Vec<bcr::models::pagination::Sort>>,
}
